Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 58 fields pub ACMPHS0: Acmphs0, pub ACMPLP: Acmplp, pub ADC160: Adc160, pub CTSU: Ctsu, pub OPAMP: Opamp, pub SDADC24: Sdadc24, pub TSN: Tsn, pub DAC12: Dac12, pub DAC8: Dac8, pub ELC: Elc, pub IWDT: Iwdt, pub KINT: Kint, pub USBFS: Usbfs, pub WDT: Wdt, pub CAC: Cac, pub CRC: Crc, pub DOC: Doc, pub SCI0: Sci0, pub SCI1: Sci1, pub SCI9: Sci1, pub SPI0: Spi0, pub SPI1: Spi0, pub CAN0: Can0, pub IIC0: Iic0, pub IIC1: Iic1, pub MMF: Mmf, pub MMPU: Mmpu, pub SMPU: Smpu, pub SPMON: Spmon, pub SRAM: Sram, pub BUS: Bus, pub DBG: Dbg, pub DTC: Dtc, pub ICU: Icu, pub SYSTEM: System, pub MSTP: Mstp, pub AGT0: Agt0, pub AGT1: Agt0, pub GPT320: Gpt320, pub GPT_OPS: GptOps, pub GPT161: Gpt161, pub GPT162: Gpt161, pub GPT163: Gpt161, pub GPT164: Gpt161, pub GPT165: Gpt161, pub GPT166: Gpt161, pub POEG: Poeg, pub RTC: Rtc, pub FCACHE: Fcache, pub PORT0: Port0, pub PORT1: Port1, pub PORT2: Port1, pub PORT3: Port0, pub PORT4: Port0, pub PORT5: Port0, pub PORT9: Port0, pub PFS: Pfs, pub PMISC: Pmisc,
}
Required for compatibility with RTIC and other frameworks

Fields

ACMPHS0: Acmphs0ACMPLP: AcmplpADC160: Adc160CTSU: CtsuOPAMP: OpampSDADC24: Sdadc24TSN: TsnDAC12: Dac12DAC8: Dac8ELC: ElcIWDT: IwdtKINT: KintUSBFS: UsbfsWDT: WdtCAC: CacCRC: CrcDOC: DocSCI0: Sci0SCI1: Sci1SCI9: Sci1SPI0: Spi0SPI1: Spi0CAN0: Can0IIC0: Iic0IIC1: Iic1MMF: MmfMMPU: MmpuSMPU: SmpuSPMON: SpmonSRAM: SramBUS: BusDBG: DbgDTC: DtcICU: IcuSYSTEM: SystemMSTP: MstpAGT0: Agt0AGT1: Agt0GPT320: Gpt320GPT_OPS: GptOpsGPT161: Gpt161GPT162: Gpt161GPT163: Gpt161GPT164: Gpt161GPT165: Gpt161GPT166: Gpt161POEG: PoegRTC: RtcFCACHE: FcachePORT0: Port0PORT1: Port1PORT2: Port1PORT3: Port0PORT4: Port0PORT5: Port0PORT9: Port0PFS: PfsPMISC: Pmisc

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks